@@ -671,4 +671,41 @@ fast_match = function(x, table, nomatch = NA_integer_, NA_incomparable = FALSE){
         }    
     }
     ind
+}
+
+#################
+
+add_class = function(x, ...){
+    new_class = unlist(list(...))
+    class(x) = union(new_class, class(x))
+    x
+}
+
+remove_class = function(x, ...){
+    new_class = unlist(list(...))
+    class(x) = setdiff(class(x), new_class)
+    x
+}
+
+############
+## copied from https://github.com/Rdatatable/data.table/blob/master/R/utils.R
+## added exclusively to workaround strange bug with data.table (issue #10)
+name_dots <- function(...) {
+    dot_sub <- as.list(substitute(list(...)))[-1L]
+    vnames = names(dot_sub)
+    if (is.null(vnames)) {
+        vnames = rep.int("", length(dot_sub))
+        novname = rep.int(TRUE, length(dot_sub))
+    } else {
+        vnames[is.na(vnames)] = ""
+        if (any(vnames==".SD")) stop("A column may not be called .SD. That has special meaning.")
+        novname = vnames==""
+    }
+    for (i in which(novname)) {
+        if ((tmp <- deparse(dot_sub[[i]])[1L]) == make.names(tmp))
+            vnames[i] = tmp
+    }
+    still_empty = vnames==""
+    if (any(still_empty)) vnames[still_empty] = paste0("V", which(still_empty))
+    list(vnames=vnames, novname=novname)
 }
\ No newline at end of file
