@@ -91,8 +91,8 @@ mtcars = within(mtcars,{
 })
 
 
-expect_equal_to_reference(summary(lm(mpg ~ ., data = names2labels(mtcars))),"rds/lm_names2labels_1.rds")
-expect_equal_to_reference(summary(lm(mpg ~ ., data = names2labels(mtcars, keep_names = TRUE))),"rds/lm_names2labels_2.rds")
+expect_equal_to_reference(summary(lm(mpg ~ ., data = names2labels(mtcars))),"rds/lm_names2labels_1.rds",  update = FALSE)
+expect_equal_to_reference(summary(lm(mpg ~ ., data = names2labels(mtcars, keep_names = TRUE))),"rds/lm_names2labels_2.rds",  update = FALSE)
 
 data(mtcars)
 mtcars = within(mtcars,{
@@ -108,4 +108,4 @@ mtcars = within(mtcars,{
     var_lab(gear) = "Number of forward gears"
     var_lab(carb) = "Number of carburetors"
 })
-expect_equal_to_reference(summary(lm(mpg ~ ., data = names2labels(mtcars, exclude = "mpg"))),"rds/lm_names2labels_3.rds")
+expect_equal_to_reference(summary(lm(mpg ~ ., data = names2labels(mtcars, exclude = "mpg"))),"rds/lm_names2labels_3.rds",  update = FALSE)
